import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  axisLeft,
  axisBottom,
  area,
  curveBasis
} from 'd3';

const svg = select('svg');
const height = +svg.attr('height');
const width = +svg.attr('width');

const render = (data) => {
  const titleLabel = "San Francisco Temperature";
  const xValue = d => d.timestamp;
  const xAxisLabel = "Time";
  const yValue = d => d.temperature;
  const yAxisLabel = "Temperature";
  
  const circleRadius = 5;

  const LR = 150;
  const TB = 80;
  const margin = { left: LR, top: TB, right: LR, bottom: TB };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;

  // Linear scales are useful for quantitative attributes.
  const xScale = scaleTime()
    .domain(extent(data, xValue))
    .range([0, innerWidth]);

  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerHeight, 0])
  	.nice();

  const g = svg
    .append('g')
    .attr('transform', `translate(${margin.left}, ${margin.top})`);
  
  const xAxis = axisBottom(xScale)
  	.ticks(5)
  	.tickSize(-innerHeight)
  	.tickPadding(15);
  
  const yAxis = axisLeft(yScale)
  	.tickSize(-innerWidth)
  	.tickPadding(5);
  
  const xAxisGroup = g.append('g')
    .call(xAxis)
    	.attr('transform', `translate(0, ${innerHeight})`);
  
  xAxisGroup.select('.domain').remove();
  xAxisGroup.append('text')
  	.attr('class', 'axis-label')
    .attr('x', innerWidth/2)
  	.attr('y', 60)
  	.attr('fill', 'black')
  	.text(xAxisLabel);
  
  const yAxisGroup = g.append('g').call(yAxis);
  
  yAxisGroup.select('.domain').remove();
  yAxisGroup.append('text')
  	.attr('class', 'axis-label')
    .attr('x', -innerHeight/2)
  	.attr('y', -55)
  	.attr('fill', 'black')
    .attr('transform', 'rotate(-90)')
  	.attr('text-anchor', 'middle')
  	.text(yAxisLabel);
  
  const areaGenerator = area()
  	.x(d => xScale(xValue(d)))
  	.y0(innerHeight)
  	.y1(d => yScale(yValue(d)))
  	.curve(curveBasis);
  
  g.append('path')
  	.attr('class', 'area-path')
  	.attr('d', areaGenerator(data));
  
  g.append('text')
		.attr('class', 'title')
  	.attr('y', -10)
  	.text(titleLabel);
};

const dataLoc = 'https://gist.githubusercontent.com/ayodhyanandh/8692fa8de4dfce09d5ef21c0e24bc168/raw/916ce599b802bb450d9de9147095b030a61e1f8d/temperature-in-san-francisco.csv';
csv(dataLoc).then(data => {
  data.forEach( d => {
    d.temperature = +d.temperature;
    d.timestamp = new Date(d.timestamp);
  });
  render(data);
});
